from aotf import *
import configparser
import os
from tkinter import *
from tkinter import tix
from tkinter.constants import *


class Application(Frame):
    '''GUI to control with AAAOTF instance.'''
    
    def __init__(self, master=None, max_power=19.0, init_power=18.0, device=None):
        Frame.__init__(self, master)
        if device != None:
            self.device = device
        # Power Variable.
        self.power = DoubleVar()
        self._init_power = init_power
        self.power.set(init_power)
        # Power Label.
        self.power_frame = tix.LabelFrame(
            root, label='Channel 1 Power (dB)',
            labelside='left',
            relief=GROOVE, borderwidth=1,
            )
        self.power_frame.pack()
        # Power SpinBox.
        self.power_frame.spinbox = tix.Control(
            self.power_frame,
            min=12.0, max=max_power, step=0.1,
            autorepeat=False,
            variable=self.power,
            )
        self.power_frame.spinbox.pack()
        self.power_frame.spinbox['command'] = self.round_power

    def round_power(self, current=17.0):
        '''Round power to 1 decimal place.'''
        new_power = round(float(current), 1)
        self.power_frame.spinbox['disablecallback'] = True
        try:
            self.power.set(new_power)
        except TclError:
            self.power.set(self._init_power)
        finally:
            self.power_frame.spinbox['disablecallback'] = False
        if self.device != None:
            self.device.power = new_power
            print('Power = {0} dB'.format(self.device.power))


if __name__ == '__main__':
    ser = AAAOTF('COM1')
    init_power = ser.power

    # Check config file for max and last set power.
    CONFIG_FILE = 'aotf.ini'
    max_power = set_power = -1
    config = configparser.RawConfigParser()
    if os.path.exists(CONFIG_FILE):
        config.read(CONFIG_FILE)
        max_power = float(config.get('Channel1', 'max_power'))
        init_power = float(config.get('Channel1', 'init_power'))
    else:
        max_power = init_power # Read from device.
        config.add_section('Channel1')
        config.set('Channel1', 'max_power', str(max_power))
        config.set('Channel1', 'init_power', str(max_power))
        with open(CONFIG_FILE, 'w') as file:
            config.write(file)

    # Create GUI.
    root = tix.Tk()
    root.title("Detune AOTF")
    app = Application(device=ser,
                      master=root,
                      max_power=max_power,
                      init_power=init_power,
                      )
    # Start GUI.
    app.mainloop()
    # Save power on GUI close.
    config.set('Channel1', 'init_power', app.power.get())
    with open(CONFIG_FILE, 'w') as file:
        config.write(file)
    # Restore max_power to device.
    ser.power = max_power
